@@ -45,11 +45,10 @@ class InfiniteCampusApiClient():
         try:
             request_url = urljoin(
                 self._base_url, (f"/campus/verify.jsp?nonBrowser=true"
-                    f"&username={self._username}"
-                    f"&password={self._secret}"
-                    f"&appName={self._district}"
-                    "&portalLoginPage=parents"
-                )
+                                 f"&username={self._username}"
+                                 f"&password={self._secret}"
+                                 f"&appName={self._district}"
+                                 "&portalLoginPage=parents")
             )
             async with session.post(request_url) as authresponse:
                 response = authresponse
